/*******************************************************************************
* File Name: Audio_In_Neg.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Audio_In_Neg.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        Audio_In_Neg_PC =   (Audio_In_Neg_PC & \
                                (uint32)(~(uint32)(Audio_In_Neg_DRIVE_MODE_IND_MASK << (Audio_In_Neg_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (Audio_In_Neg_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: Audio_In_Neg_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Audio_In_Neg_Write(uint8 value) 
{
    uint8 drVal = (uint8)(Audio_In_Neg_DR & (uint8)(~Audio_In_Neg_MASK));
    drVal = (drVal | ((uint8)(value << Audio_In_Neg_SHIFT) & Audio_In_Neg_MASK));
    Audio_In_Neg_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: Audio_In_Neg_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Audio_In_Neg_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(Audio_In_Neg__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: Audio_In_Neg_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Audio_In_Neg_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Audio_In_Neg_Read(void) 
{
    return (uint8)((Audio_In_Neg_PS & Audio_In_Neg_MASK) >> Audio_In_Neg_SHIFT);
}


/*******************************************************************************
* Function Name: Audio_In_Neg_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Audio_In_Neg_ReadDataReg(void) 
{
    return (uint8)((Audio_In_Neg_DR & Audio_In_Neg_MASK) >> Audio_In_Neg_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Audio_In_Neg_INTSTAT) 

    /*******************************************************************************
    * Function Name: Audio_In_Neg_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Audio_In_Neg_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(Audio_In_Neg_INTSTAT & Audio_In_Neg_MASK);
		Audio_In_Neg_INTSTAT = maskedStatus;
        return maskedStatus >> Audio_In_Neg_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
