/*******************************************************************************
* File Name: PWM_Tick.c
* Version 1.0
*
* Description:
*  This file provides the source code to the API for the PWM_Tick
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PWM_Tick.h"
#include "CyLib.h"

uint8 PWM_Tick_initVar = 0u;


/*******************************************************************************
* Function Name: PWM_Tick_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default PWM_Tick configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (PWM_Tick__QUAD == PWM_Tick_CONFIG)
        PWM_Tick_CONTROL_REG =
        (((uint32)(PWM_Tick_QUAD_ENCODING_MODES     << PWM_Tick_QUAD_MODE_SHIFT))       |
         ((uint32)(PWM_Tick_CONFIG                  << PWM_Tick_MODE_SHIFT)));
    #endif  /* (PWM_Tick__QUAD == PWM_Tick_CONFIG) */

    #if (PWM_Tick__PWM_SEL == PWM_Tick_CONFIG)
        PWM_Tick_CONTROL_REG =
        (((uint32)(PWM_Tick_PWM_STOP_EVENT          << PWM_Tick_PWM_STOP_KILL_SHIFT))    |
         ((uint32)(PWM_Tick_PWM_OUT_INVERT          << PWM_Tick_INV_OUT_SHIFT))         |
         ((uint32)(PWM_Tick_PWM_OUT_N_INVERT        << PWM_Tick_INV_COMPL_OUT_SHIFT))     |
         ((uint32)(PWM_Tick_PWM_MODE                << PWM_Tick_MODE_SHIFT)));

        #if (PWM_Tick__PWM_PR == PWM_Tick_PWM_MODE)
            PWM_Tick_CONTROL_REG |=
            ((uint32)(PWM_Tick_PWM_RUN_MODE         << PWM_Tick_ONESHOT_SHIFT));

            PWM_Tick_WriteCounter(PWM_Tick_PWM_PR_INIT_VALUE);
        #else
            PWM_Tick_CONTROL_REG |=
            (((uint32)(PWM_Tick_PWM_ALIGN           << PWM_Tick_UPDOWN_SHIFT))          |
             ((uint32)(PWM_Tick_PWM_KILL_EVENT      << PWM_Tick_PWM_SYNC_KILL_SHIFT)));
        #endif  /* (PWM_Tick__PWM_PR == PWM_Tick_PWM_MODE) */

        #if (PWM_Tick__PWM_DT == PWM_Tick_PWM_MODE)
            PWM_Tick_CONTROL_REG |=
            ((uint32)(PWM_Tick_PWM_DEAD_TIME_CYCLE  << PWM_Tick_PRESCALER_SHIFT));
        #endif  /* (PWM_Tick__PWM_DT == PWM_Tick_PWM_MODE) */

        #if (PWM_Tick__PWM == PWM_Tick_PWM_MODE)
            PWM_Tick_CONTROL_REG |=
            ((uint32)PWM_Tick_PWM_PRESCALER         << PWM_Tick_PRESCALER_SHIFT);
        #endif  /* (PWM_Tick__PWM == PWM_Tick_PWM_MODE) */
    #endif  /* (PWM_Tick__PWM_SEL == PWM_Tick_CONFIG) */

    #if (PWM_Tick__TIMER == PWM_Tick_CONFIG)
        PWM_Tick_CONTROL_REG =
        (((uint32)(PWM_Tick_TC_PRESCALER            << PWM_Tick_PRESCALER_SHIFT))   |
         ((uint32)(PWM_Tick_TC_COUNTER_MODE         << PWM_Tick_UPDOWN_SHIFT))      |
         ((uint32)(PWM_Tick_TC_RUN_MODE             << PWM_Tick_ONESHOT_SHIFT))     |
         ((uint32)(PWM_Tick_TC_COMP_CAP_MODE        << PWM_Tick_MODE_SHIFT)));
    #endif  /* (PWM_Tick__TIMER == PWM_Tick_CONFIG) */

    /* Set values from customizer to CTRL1 */
    #if (PWM_Tick__QUAD == PWM_Tick_CONFIG)
        PWM_Tick_TRIG_CONTROL1_REG  =
        (((uint32)(PWM_Tick_QUAD_PHIA_SIGNAL_MODE   << PWM_Tick_COUNT_SHIFT))       |
         ((uint32)(PWM_Tick_QUAD_INDEX_SIGNAL_MODE  << PWM_Tick_RELOAD_SHIFT))      |
         ((uint32)(PWM_Tick_QUAD_STOP_SIGNAL_MODE   << PWM_Tick_STOP_SHIFT))        |
         ((uint32)(PWM_Tick_QUAD_PHIB_SIGNAL_MODE   << PWM_Tick_START_SHIFT)));
    #endif  /* (PWM_Tick__QUAD == PWM_Tick_CONFIG) */

    #if (PWM_Tick__PWM_SEL == PWM_Tick_CONFIG)
        PWM_Tick_TRIG_CONTROL1_REG  =
        (((uint32)(PWM_Tick_PWM_SWITCH_SIGNAL_MODE  << PWM_Tick_CAPTURE_SHIFT))     |
         ((uint32)(PWM_Tick_PWM_COUNT_SIGNAL_MODE   << PWM_Tick_COUNT_SHIFT))       |
         ((uint32)(PWM_Tick_PWM_RELOAD_SIGNAL_MODE  << PWM_Tick_RELOAD_SHIFT))      |
         ((uint32)(PWM_Tick_PWM_STOP_SIGNAL_MODE    << PWM_Tick_STOP_SHIFT))        |
         ((uint32)(PWM_Tick_PWM_START_SIGNAL_MODE   << PWM_Tick_START_SHIFT)));
    #endif  /* (PWM_Tick__PWM_SEL == PWM_Tick_CONFIG) */

    #if (PWM_Tick__TIMER == PWM_Tick_CONFIG)
        PWM_Tick_TRIG_CONTROL1_REG  =
        (((uint32)(PWM_Tick_TC_CAPTURE_SIGNAL_MODE  << PWM_Tick_CAPTURE_SHIFT))     |
         ((uint32)(PWM_Tick_TC_COUNT_SIGNAL_MODE    << PWM_Tick_COUNT_SHIFT))       |
         ((uint32)(PWM_Tick_TC_RELOAD_SIGNAL_MODE   << PWM_Tick_RELOAD_SHIFT))      |
         ((uint32)(PWM_Tick_TC_STOP_SIGNAL_MODE     << PWM_Tick_STOP_SHIFT))        |
         ((uint32)(PWM_Tick_TC_START_SIGNAL_MODE    << PWM_Tick_START_SHIFT)));
    #endif  /* (PWM_Tick__TIMER == PWM_Tick_CONFIG) */

    /* Set values from customizer to INTR */
    #if (PWM_Tick__QUAD == PWM_Tick_CONFIG)
        PWM_Tick_SetInterruptMode(PWM_Tick_QUAD_INTERRUPT_MASK);
    #endif  /* (PWM_Tick__QUAD == PWM_Tick_CONFIG) */

    #if (PWM_Tick__PWM_SEL == PWM_Tick_CONFIG)
        PWM_Tick_SetInterruptMode(PWM_Tick_PWM_INTERRUPT_MASK);
    #endif  /* (PWM_Tick__PWM_SEL == PWM_Tick_CONFIG) */

    #if (PWM_Tick__TIMER == PWM_Tick_CONFIG)
        PWM_Tick_SetInterruptMode(PWM_Tick_TC_INTERRUPT_MASK);
    #endif  /* (PWM_Tick__TIMER == PWM_Tick_CONFIG) */

    /* Set other values from customizer */
    #if (PWM_Tick__TIMER == PWM_Tick_CONFIG)
        PWM_Tick_WritePeriod(PWM_Tick_TC_PERIOD_VALUE );
        #if (PWM_Tick__COMPARE == PWM_Tick_TC_COMP_CAP_MODE)
            PWM_Tick_WriteCompare(PWM_Tick_TC_COMPARE_VALUE);

            #if (1u == PWM_Tick_TC_COMPARE_SWAP)
                PWM_Tick_SetCompareSwap(1u);
                PWM_Tick_WriteCompareBuf(PWM_Tick_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == PWM_Tick_TC_COMPARE_SWAP) */
        #endif  /* (PWM_Tick__COMPARE == PWM_Tick_TC_COMP_CAP_MODE) */
    #endif  /* (PWM_Tick__TIMER == PWM_Tick_CONFIG) */

    #if (PWM_Tick__PWM_SEL == PWM_Tick_CONFIG)
        PWM_Tick_WritePeriod(PWM_Tick_PWM_PERIOD_VALUE );
        PWM_Tick_WriteCompare(PWM_Tick_PWM_COMPARE_VALUE);

        #if (1u == PWM_Tick_PWM_COMPARE_SWAP)
            PWM_Tick_SetCompareSwap(1u);
            PWM_Tick_WriteCompareBuf(PWM_Tick_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == PWM_Tick_PWM_COMPARE_SWAP) */

        #if (1u == PWM_Tick_PWM_PERIOD_SWAP)
            PWM_Tick_SetPeriodSwap(1u);
            PWM_Tick_WritePeriodBuf(PWM_Tick_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == PWM_Tick_PWM_PERIOD_SWAP) */

        /* Set values from customizer to CTRL2 */
        #if (PWM_Tick__PWM_PR == PWM_Tick_PWM_MODE)
            PWM_Tick_TRIG_CONTROL2_REG =
                    (PWM_Tick_CC_MATCH_NO_CHANGE    |
                    PWM_Tick_OVERLOW_NO_CHANGE      |
                    PWM_Tick_UNDERFLOW_NO_CHANGE);
        #else
            #if (PWM_Tick__LEFT == PWM_Tick_PWM_ALIGN)
                PWM_Tick_TRIG_CONTROL2_REG = PWM_Tick_PWM_MODE_LEFT;
            #endif  /* ( PWM_Tick_PWM_LEFT == PWM_Tick_PWM_ALIGN) */

            #if (PWM_Tick__RIGHT == PWM_Tick_PWM_ALIGN)
                PWM_Tick_TRIG_CONTROL2_REG = PWM_Tick_PWM_MODE_RIGHT;
            #endif  /* ( PWM_Tick_PWM_RIGHT == PWM_Tick_PWM_ALIGN) */

            #if (PWM_Tick__CENTER == PWM_Tick_PWM_ALIGN)
                PWM_Tick_TRIG_CONTROL2_REG = PWM_Tick_PWM_MODE_CENTER;
            #endif  /* ( PWM_Tick_PWM_CENTER == PWM_Tick_PWM_ALIGN) */

            #if (PWM_Tick__ASYMMETRIC == PWM_Tick_PWM_ALIGN)
                PWM_Tick_TRIG_CONTROL2_REG = PWM_Tick_PWM_MODE_ASYM;
            #endif  /* (PWM_Tick__ASYMMETRIC == PWM_Tick_PWM_ALIGN) */
        #endif  /* (PWM_Tick__PWM_PR == PWM_Tick_PWM_MODE) */
    #endif  /* (PWM_Tick__PWM_SEL == PWM_Tick_CONFIG) */
}


/*******************************************************************************
* Function Name: PWM_Tick_Enable
********************************************************************************
*
* Summary:
*  Enables the PWM_Tick.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    PWM_Tick_BLOCK_CONTROL_REG |= PWM_Tick_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Statr Timer or PWM if start input is absent */
    #if (PWM_Tick__PWM_SEL == PWM_Tick_CONFIG)
        #if (0u == PWM_Tick_PWM_START_SIGNAL_PRESENT)
            PWM_Tick_TriggerCommand(PWM_Tick_MASK, PWM_Tick_CMD_START);
        #endif /* (0u == PWM_Tick_PWM_START_SIGNAL_PRESENT) */
    #endif /* (PWM_Tick__PWM_SEL == PWM_Tick_CONFIG) */

    #if (PWM_Tick__TIMER == PWM_Tick_CONFIG)
        #if (0u == PWM_Tick_TC_START_SIGNAL_PRESENT)
            PWM_Tick_TriggerCommand(PWM_Tick_MASK, PWM_Tick_CMD_START);
        #endif /* (0u == PWM_Tick_TC_START_SIGNAL_PRESENT) */
    #endif /* (PWM_Tick__TIMER == PWM_Tick_CONFIG) */
}


/*******************************************************************************
* Function Name: PWM_Tick_Start
********************************************************************************
*
* Summary:
*  Initialize the PWM_Tick with default customizer
*  values when called the first time and enables the PWM_Tick.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  PWM_Tick_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time PWM_Tick_Start() is called. This allows
*  enable/disable component without re-initialization in all subsequent calls
*  to the PWM_Tick_Start() routine.
*
*******************************************************************************/
void PWM_Tick_Start(void)
{
    if (0u == PWM_Tick_initVar)
    {
        PWM_Tick_Init();
        PWM_Tick_initVar = 1u;
    }

    PWM_Tick_Enable();
}


/*******************************************************************************
* Function Name: PWM_Tick_Stop
********************************************************************************
*
* Summary:
*  Disables the PWM_Tick.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_BLOCK_CONTROL_REG &= (uint32)~PWM_Tick_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the PWM_Tick. This function is used when
*  configured as a generic PWM_Tick and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the PWM_Tick to operate in
*   Values:
*   - PWM_Tick_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - PWM_Tick_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - PWM_Tick_MODE_QUAD - Quadrature decoder
*         - PWM_Tick_MODE_PWM - PWM
*         - PWM_Tick_MODE_PWM_DT - PWM with dead time
*         - PWM_Tick_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_MODE_MASK;
    PWM_Tick_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of 3 supported modes.
*  Is functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - PWM_Tick_MODE_X1 - Counts on phi 1 rising
*         - PWM_Tick_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - PWM_Tick_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_QUAD_MODE_MASK;
    PWM_Tick_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to PWM with dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - PWM_Tick_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - PWM_Tick_PRESCALE_DIVBY2    - Divide by 2
*         - PWM_Tick_PRESCALE_DIVBY4    - Divide by 4
*         - PWM_Tick_PRESCALE_DIVBY8    - Divide by 8
*         - PWM_Tick_PRESCALE_DIVBY16   - Divide by 16
*         - PWM_Tick_PRESCALE_DIVBY32   - Divide by 32
*         - PWM_Tick_PRESCALE_DIVBY64   - Divide by 64
*         - PWM_Tick_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_PRESCALER_MASK;
    PWM_Tick_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM_Tick runs
*  continuously or stops when terminal count is reached.  By default the
*  PWM_Tick operates in continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_ONESHOT_MASK;
    PWM_Tick_CONTROL_REG |= ((uint32)((oneShotEnable & PWM_Tick_1BIT_MASK) <<
                                                               PWM_Tick_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the 3 must be ORed together to form the
*  mode.
*
* Parameters:
*  modeMask: Combination of the 3 mode settings.  Mask must include a value for
*  each of the 3 or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be 
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetPWMMode(uint32 modeMask)
{
    PWM_Tick_TRIG_CONTROL2_REG = (modeMask & PWM_Tick_6BIT_MASK);
}



/*******************************************************************************
* Function Name: PWM_Tick_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes an asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to PWM and
*  PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_PWM_SYNC_KILL_MASK;
    PWM_Tick_CONTROL_REG |= ((uint32)((syncKillEnable & PWM_Tick_1BIT_MASK)  <<
                                               PWM_Tick_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_PWM_STOP_KILL_MASK;
    PWM_Tick_CONTROL_REG |= ((uint32)((stopOnKillEnable & PWM_Tick_1BIT_MASK)  <<
                                                         PWM_Tick_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_PRESCALER_MASK;
    PWM_Tick_CONTROL_REG |= ((uint32)((deadTime & PWM_Tick_8BIT_MASK) <<
                                                          PWM_Tick_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - PWM_Tick_INVERT_LINE   - Inverts the line output
*         - PWM_Tick_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_INV_OUT_MASK;
    PWM_Tick_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: PWM_Tick_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_WriteCounter(uint32 count)
{
    PWM_Tick_COUNTER_REG = (count & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 PWM_Tick_ReadCounter(void)
{
    return (PWM_Tick_COUNTER_REG & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and PWM with pseudo random output.
*
* Parameters:
*  counterMode: Enumerated couner type values
*   Values:
*     - PWM_Tick_COUNT_UP       - Counts up
*     - PWM_Tick_COUNT_DOWN     - Counts down
*     - PWM_Tick_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - PWM_Tick_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_UPDOWN_MASK;
    PWM_Tick_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_WritePeriod(uint32 period)
{
    PWM_Tick_PERIOD_REG = (period & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 PWM_Tick_ReadPeriod(void)
{
    return (PWM_Tick_PERIOD_REG & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in Timer/Counter mode(without capture) the swap occurs
*  at a TC event. In PWM mode the swap occurs at the next TC event following
*  a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_RELOAD_CC_MASK;
    PWM_Tick_CONTROL_REG |= (swapEnable & PWM_Tick_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_WritePeriodBuf(uint32 periodBuf)
{
    PWM_Tick_PERIOD_BUF_REG = (periodBuf & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 PWM_Tick_ReadPeriodBuf(void)
{
    return (PWM_Tick_PERIOD_BUF_REG & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In PWM mode the swap occurs at the next TC event following a hardware switch
*  event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_CONTROL_REG &= (uint32)~PWM_Tick_RELOAD_PERIOD_MASK;
    PWM_Tick_CONTROL_REG |= ((uint32)((swapEnable & PWM_Tick_1BIT_MASK) <<
                                                            PWM_Tick_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_WriteCompare(uint32 compare)
{
    PWM_Tick_COMP_CAP_REG = (compare & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
*******************************************************************************/
uint32 PWM_Tick_ReadCompare(void)
{
    return (PWM_Tick_COMP_CAP_REG & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_WriteCompareBuf(uint32 compareBuf)
{
   PWM_Tick_COMP_CAP_BUF_REG = (compareBuf & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
*******************************************************************************/
uint32 PWM_Tick_ReadCompareBuf(void)
{
    return (PWM_Tick_COMP_CAP_BUF_REG & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 PWM_Tick_ReadCapture(void)
{
    return (PWM_Tick_COMP_CAP_REG & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 PWM_Tick_ReadCaptureBuf(void)
{
    return (PWM_Tick_COMP_CAP_BUF_REG & PWM_Tick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PWM_Tick_TRIG_LEVEL     - Level
*     - PWM_Tick_TRIG_RISING    - Rising edge
*     - PWM_Tick_TRIG_FALLING   - Falling edge
*     - PWM_Tick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_TRIG_CONTROL1_REG &= (uint32)~PWM_Tick_CAPTURE_MASK;
    PWM_Tick_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PWM_Tick_TRIG_LEVEL     - Level
*     - PWM_Tick_TRIG_RISING    - Rising edge
*     - PWM_Tick_TRIG_FALLING   - Falling edge
*     - PWM_Tick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_TRIG_CONTROL1_REG &= (uint32)~PWM_Tick_RELOAD_MASK;
    PWM_Tick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PWM_Tick_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PWM_Tick_TRIG_LEVEL     - Level
*     - PWM_Tick_TRIG_RISING    - Rising edge
*     - PWM_Tick_TRIG_FALLING   - Falling edge
*     - PWM_Tick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_TRIG_CONTROL1_REG &= (uint32)~PWM_Tick_START_MASK;
    PWM_Tick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PWM_Tick_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PWM_Tick_TRIG_LEVEL     - Level
*     - PWM_Tick_TRIG_RISING    - Rising edge
*     - PWM_Tick_TRIG_FALLING   - Falling edge
*     - PWM_Tick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_TRIG_CONTROL1_REG &= (uint32)~PWM_Tick_STOP_MASK;
    PWM_Tick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PWM_Tick_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PWM_Tick_TRIG_LEVEL     - Level
*     - PWM_Tick_TRIG_RISING    - Rising edge
*     - PWM_Tick_TRIG_FALLING   - Falling edge
*     - PWM_Tick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_TRIG_CONTROL1_REG &= (uint32)~PWM_Tick_COUNT_MASK;
    PWM_Tick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PWM_Tick_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: Combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - PWM_Tick_CMD_CAPTURE    - Trigger Capture command
*     - PWM_Tick_CMD_RELOAD     - Trigger Reload command
*     - PWM_Tick_CMD_STOP       - Trigger Stop command
*     - PWM_Tick_CMD_START      - Trigger Start command
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWM_Tick_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWM_Tick_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the PWM_Tick.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - PWM_Tick_STATUS_DOWN    - Set if counting down
*     - PWM_Tick_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 PWM_Tick_ReadStatus(void)
{
    return ((PWM_Tick_STATUS_REG >> PWM_Tick_RUNNING_STATUS_SHIFT) |
            (PWM_Tick_STATUS_REG & PWM_Tick_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: PWM_Tick_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - PWM_Tick_INTR_MASK_TC       - Terminal count mask
*     - PWM_Tick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetInterruptMode(uint32 interruptMask)
{
    PWM_Tick_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: PWM_Tick_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - PWM_Tick_INTR_MASK_TC       - Terminal count mask
*     - PWM_Tick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 PWM_Tick_GetInterruptSourceMasked(void)
{
    return (PWM_Tick_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: PWM_Tick_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - PWM_Tick_INTR_MASK_TC       - Terminal count mask
*     - PWM_Tick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 PWM_Tick_GetInterruptSource(void)
{
    return (PWM_Tick_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: PWM_Tick_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - PWM_Tick_INTR_MASK_TC       - Terminal count mask
*     - PWM_Tick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_ClearInterrupt(uint32 interruptMask)
{
    PWM_Tick_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: PWM_Tick_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - PWM_Tick_INTR_MASK_TC       - Terminal count mask
*     - PWM_Tick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Tick_SetInterrupt(uint32 interruptMask)
{
    PWM_Tick_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
